@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -30,11 +30,12 @@ sub Run {
     my ( $Self, %Param ) = @_;
 
     # get needed objects
-    my $ParamObject        = $Kernel::OM->Get('Kernel::System::Web::Request');
-    my $LayoutObject       = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
-    my $CustomerUserObject = $Kernel::OM->Get('Kernel::System::CustomerUser');
-    my $ConfigObject       = $Kernel::OM->Get('Kernel::Config');
-    my $TicketObject       = $Kernel::OM->Get('Kernel::System::Ticket');
+    my $ParamObject           = $Kernel::OM->Get('Kernel::System::Web::Request');
+    my $LayoutObject          = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
+    my $CustomerUserObject    = $Kernel::OM->Get('Kernel::System::CustomerUser');
+    my $ConfigObject          = $Kernel::OM->Get('Kernel::Config');
+    my $TicketObject          = $Kernel::OM->Get('Kernel::System::Ticket');
+    my $CustomerCompanyObject = $Kernel::OM->Get('Kernel::System::CustomerCompany');
 
     my $AutoCompleteConfig            = $ConfigObject->Get('AutoComplete::Agent')->{CustomerSearch};
     my $MaxResults                    = $AutoCompleteConfig->{MaxResultsDisplayed} || 20;
@@ -54,11 +55,18 @@ sub Run {
             );
         }
 
-        my %CustomerCompanyList = $Kernel::OM->Get('Kernel::System::CustomerCompany')->CustomerCompanyList(
+        # Search for Valid customer companies.
+        my %CustomerCompanyList = $CustomerCompanyObject->CustomerCompanyList(
             Search => $SearchTerm,
         );
         map { $CustomerCompanyList{$_} = $UnknownTicketCustomerList->{$_} } keys %{$UnknownTicketCustomerList};
 
+        # Search for all customer companies, valid and invalid.
+        my %CustomerCompanyListAll = $CustomerCompanyObject->CustomerCompanyList(
+            Search => $SearchTerm,
+            Valid  => 0,
+        );
+
         my @CustomerIDs = $CustomerUserObject->CustomerIDList(
             SearchTerm => $SearchTerm,
         );
@@ -72,7 +80,7 @@ sub Run {
             $Seen{$CustomerID} = 1;
 
             # identifies unknown companies
-            if ( !exists $CustomerCompanyList{$CustomerID} ) {
+            if ( !exists $CustomerCompanyListAll{$CustomerID} ) {
                 $CustomerCompanyList{$CustomerID} = $CustomerID;
             }
 
@@ -128,13 +136,13 @@ sub Run {
             my %CustomerData = $CustomerUserObject->CustomerUserDataGet(
                 User => $CustomerLogin,
             );
-            if ( !( grep { $_->{Value} eq $CustomerData{UserCustomerID} } @Result ) ) {
-                push @Result,
-                    {
-                    Label => $CustomerList{$CustomerLogin},
-                    Value => $CustomerData{UserCustomerID}
-                    };
-            }
+
+            push @Result,
+                {
+                Label => $CustomerList{$CustomerLogin},
+                Value => $CustomerData{UserCustomerID}
+                };
+
             last CUSTOMERLOGIN if scalar @Result >= $MaxResults;
 
         }
