@@ -1,15 +1,11 @@
 # --
-# Ticket/Number/Date.pm - a date ticket number generator
-# Copyright (C) 2001-2013 OTRS AG, http://otrs.org/
-# --
-# $Id: Date.pm,v 1.34 2013/02/01 13:14:05 mg Exp $
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
 # did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
-# Note:
-# available objects are: ConfigObject, LogObject and DBObject
+
 #
 # Generates ticket numbers like yyyymmddss.... (e. g. 200206231010138)
 # --
@@ -19,36 +15,49 @@ package Kernel::System::Ticket::Number::Date;
 use strict;
 use warnings;
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.34 $) [1];
+our @ObjectDependencies = (
+    'Kernel::Config',
+    'Kernel::System::Log',
+    'Kernel::System::Main',
+    'Kernel::System::Time',
+);
 
 sub TicketCreateNumber {
     my ( $Self, $JumpCounter ) = @_;
+
     if ( !$JumpCounter ) {
         $JumpCounter = 0;
     }
 
+    # get needed objects
+    my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
+    my $MainObject   = $Kernel::OM->Get('Kernel::System::Main');
+    my $TimeObject   = $Kernel::OM->Get('Kernel::System::Time');
+
     # get needed config options
-    my $CounterLog = $Self->{ConfigObject}->Get('Ticket::CounterLog');
-    my $SystemID   = $Self->{ConfigObject}->Get('SystemID');
+    my $CounterLog = $ConfigObject->Get('Ticket::CounterLog');
+    my $SystemID   = $ConfigObject->Get('SystemID');
 
     # get current time
-    my ( $Sec, $Min, $Hour, $Day, $Month, $Year ) = $Self->{TimeObject}->SystemTime2Date(
-        SystemTime => $Self->{TimeObject}->SystemTime(),
+    my ( $Sec, $Min, $Hour, $Day, $Month, $Year ) = $TimeObject->SystemTime2Date(
+        SystemTime => $TimeObject->SystemTime(),
     );
 
     # read count
     my $Count = 0;
     if ( -f $CounterLog ) {
-        my $ContentSCALARRef = $Self->{MainObject}->FileRead(
+
+        my $ContentSCALARRef = $MainObject->FileRead(
             Location => $CounterLog,
         );
+
         if ( $ContentSCALARRef && ${$ContentSCALARRef} ) {
+
             ($Count) = split( /;/, ${$ContentSCALARRef} );
 
             # just debug
             if ( $Self->{Debug} > 0 ) {
-                $Self->{LogObject}->Log(
+                $Kernel::OM->Get('Kernel::System::Log')->Log(
                     Priority => 'debug',
                     Message  => "Read counter from $CounterLog: $Count",
                 );
@@ -61,29 +70,39 @@ sub TicketCreateNumber {
     $Count = $Count + $JumpCounter;
 
     # write new count
-    my $Write = $Self->{MainObject}->FileWrite(
+    my $Write = $MainObject->FileWrite(
         Location => $CounterLog,
         Content  => \$Count,
     );
+
     if ($Write) {
+
         if ( $Self->{Debug} > 0 ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'debug',
                 Message  => "Write counter: $Count",
             );
         }
     }
 
+    if ( $ConfigObject->Get('Ticket::NumberGenerator::Date::UseFormattedCounter') ) {
+        my $MinSize = $ConfigObject->Get('Ticket::NumberGenerator::MinCounterSize')
+            || 5;
+        $Count = sprintf "%.*u", $MinSize, $Count;
+    }
+
     # create new ticket number
     my $Tn = $Year . $Month . $Day . $SystemID . $Count;
 
     # Check ticket number. If exists generate new one!
-    if ( $Self->TicketCheckNumber( Tn => $Tn ) ) {
+    if ( $Self->TicketIDLookup( TicketNumber => $Tn ) ) {
+
         $Self->{LoopProtectionCounter}++;
+
         if ( $Self->{LoopProtectionCounter} >= 16000 ) {
 
             # loop protection
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "CounterLoopProtection is now $Self->{LoopProtectionCounter}!"
                     . " Stopped TicketCreateNumber()!",
@@ -92,29 +111,37 @@ sub TicketCreateNumber {
         }
 
         # create new ticket number again
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'notice',
             Message  => "Tn ($Tn) exists! Creating a new one.",
         );
+
         $Tn = $Self->TicketCreateNumber( $Self->{LoopProtectionCounter} );
     }
+
     return $Tn;
 }
 
 sub GetTNByString {
     my ( $Self, $String ) = @_;
+
     if ( !$String ) {
         return;
     }
 
+    # get config object
+    my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
+
     # get needed config options
-    my $CheckSystemID = $Self->{ConfigObject}->Get('Ticket::NumberGenerator::CheckSystemID');
+    my $CheckSystemID = $ConfigObject->Get('Ticket::NumberGenerator::CheckSystemID');
     my $SystemID      = '';
+
     if ($CheckSystemID) {
-        $SystemID = $Self->{ConfigObject}->Get('SystemID');
+        $SystemID = $ConfigObject->Get('SystemID');
     }
-    my $TicketHook        = $Self->{ConfigObject}->Get('Ticket::Hook');
-    my $TicketHookDivider = $Self->{ConfigObject}->Get('Ticket::HookDivider');
+
+    my $TicketHook        = $ConfigObject->Get('Ticket::Hook');
+    my $TicketHookDivider = $ConfigObject->Get('Ticket::HookDivider');
 
     # check current setting
     if ( $String =~ /\Q$TicketHook$TicketHookDivider\E(\d{8}$SystemID\d{1,40})/i ) {
