@@ -22,6 +22,7 @@ use Kernel::System::UnitTest::Helper;
 
 our @ObjectDependencies = (
     'Kernel::Config',
+    'Kernel::System::AuthSession',
     'Kernel::System::Log',
     'Kernel::System::Main',
     'Kernel::System::Time',
@@ -54,18 +55,31 @@ To do this, you need a running C<selenium> or C<phantomjs> server.
 
 Specify the connection details in C<Config.pm>, like this:
 
+    # For testing with Firefox until v. 47 (testing with recent FF and marionette is currently not supported):
     $Self->{'SeleniumTestsConfig'} = {
         remote_server_addr  => 'localhost',
         port                => '4444',
-        browser_name        => 'phantomjs',
         platform            => 'ANY',
-        window_height       => 1200,    # optional, default 1000
-        window_width        => 1600,    # optional, default 1200
+        browser_name        => 'firefox',
         extra_capabilities => {
             marionette     => \0,   # Required to run FF 47 or older on Selenium 3+.
         },
     };
 
+    # For testing with Chrome/Chromium (requires installed geckodriver):
+    $Self->{'SeleniumTestsConfig'} = {
+        remote_server_addr  => 'localhost',
+        port                => '4444',
+        platform            => 'ANY',
+        browser_name        => 'chrome',
+        extra_capabilities => {
+            chromeOptions => {
+                # disable-infobars makes sure window size calculations are ok
+                args => [ "disable-infobars" ],
+            },
+        },
+    };
+
 Then you can use the full API of L<Selenium::Remote::Driver> on this object.
 
 =cut
@@ -115,6 +129,9 @@ sub new {
     $Self->{BaseURL} = $Kernel::OM->Get('Kernel::Config')->Get('HttpType') . '://';
     $Self->{BaseURL} .= Kernel::System::UnitTest::Helper->GetTestHTTPHostname();
 
+    # Remember the start system time for the selenium test run.
+    $Self->{TestStartSystemTime} = $Kernel::OM->Get('Kernel::System::Time')->SystemTime();
+
     return $Self;
 }
 
@@ -529,6 +546,22 @@ sub DEMOLISH {
             File::Path::remove_tree($LeftoverFirefoxProfile);
         }
     }
+
+    # Cleanup all sessions, which was created after the selenium test start time.
+    my $AuthSessionObject = $Kernel::OM->Get('Kernel::System::AuthSession');
+
+    my @Sessions = $AuthSessionObject->GetAllSessionIDs();
+
+    SESSION:
+    for my $SessionID (@Sessions) {
+
+        my %SessionData = $AuthSessionObject->GetSessionIDData( SessionID => $SessionID );
+
+        next SESSION if !%SessionData;
+        next SESSION if $SessionData{UserSessionStart} && $SessionData{UserSessionStart} < $Self->{TestStartSystemTime};
+
+        $AuthSessionObject->RemoveSessionID( SessionID => $SessionID );
+    }
 }
 
 1;
